@@ -1,7 +1,7 @@
 # coding: utf-8
 
 from vxci.get_addons import get_module_list, get_modules2test
-from vxbase import types, net, fromenv
+from vxbase import vtypes, net, fromenv
 from vxci.tools_test import install_chrome_commands
 import distutils.spawn
 from docker import errors, from_env
@@ -131,7 +131,7 @@ def push_image(config, image_name, image_tag):
     for attempt in range(4):
         try:
             for result in _cli.push(img_repo, tag=image_tag, stream=True):
-                result = json.loads(types.decode(result))
+                result = json.loads(vtypes.decode(result))
                 if result.get('error'):
                     _logger.error(result.get('error'))
                     sys.exit(1)
@@ -147,6 +147,10 @@ def push_image(config, image_name, image_tag):
 
 
 def notify_orchest(config, is_latest=False):
+    if not config.get('ci_project_id', '').isdigit():
+        _logger.warning('No project id defined or is a string, not notifying to Orchest')
+        return
+
     img_repo = config.get('docker_image_repo') or config['image_repo']
     image_name = '{image}:{tag}'.format(image=img_repo, tag=config['image_tag'])
     res = requests.post(
@@ -299,7 +303,7 @@ def scan_keys(folder):
                               'from this provider, please try again later'), host)
                 _logger.warn('Error was: %s', error.output)
             else:
-                for line in types.decode(keys).split('\n'):
+                for line in vtypes.decode(keys).split('\n'):
                     clean = line.strip()
                     if clean:
                         known_file.write(clean + '\n')
@@ -428,12 +432,12 @@ def exec_cmd(container, cmd, user=None, stream=False, workdir=None, tty=False):
     if stream:
         _logger.info("--->> Start of the stream <<---")
         for line in res:
-            line = types.decode(line)
+            line = vtypes.decode(line)
             print(line.strip('\n'))
             lines.append(line)
         _logger.info("--->> End of the stream <<---")
         return lines
-    return types.decode(res)
+    return vtypes.decode(res)
 
 
 def create_postgres_user(config):
